#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 idris
version:              1.3.4
visibility:           public
id:                   idris-1.3.4-LDx4LQHqml5El0xThFEtFF
key:                  idris-1.3.4-LDx4LQHqml5El0xThFEtFF
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  131ed262f7d51622fabf81b16ed471a8
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-9.6.6/site-local/idris-1.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/idris-1.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/idris-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.4-LDx4LQHqml5El0xThFEtFF
extra-libraries:      gmp
depends:
    aeson-2.2.2.0-EjtcViUIVMXBXClGtNnj1W
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-G6GN5PMYp5NGFUNAfhx5GN
    ansi-wl-pprint-1.0.2-AN7m154JoXG2rOvuW5nxgH array-0.5.6.0
    async-2.2.6-9SkVXCaD6xtG9Q9oLNb0PF base-4.18.2.1
    base64-bytestring-1.2.1.0-3sV69hgoSWS1a2SgImTi0f binary-0.8.9.1
    blaze-html-0.9.2.0-KZMAMNkPI6c1nayVkkxKRi
    blaze-markup-0.8.3.0-CI2lOOWp0vT3rzKexZclBf bytestring-0.11.5.3
    cheapskate-0.1.1.2-HB8QwMP8MD2KbnQ6HpIYk9
    code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    fingertree-0.1.6.3-76bpSODRz254ZTDwOuUo6u
    fsnotify-0.4.4.0-HbfcQMlpGSg8B9abhNIBl3 haskeline-0.8.2.1
    ieee754-0.8.0-EGVgNa4vggOEmRT3C9pqtp
    libffi-0.2.1-6RvgivFZ04x2a0O1QsDmY2
    megaparsec-9.7.1-7YgW9mASb9i33ymNY6ouD0 mtl-2.3.1
    network-3.1.4.0-Dw21gcQ0zRE10R3MPv5g8s
    optparse-applicative-0.18.1.0-72ySYnQcAhaEf71plWxl77
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m pretty-1.1.3.6
    process-1.6.19.0 regex-tdfa-1.3.2.6-GDn4kuvUrdrF2TzBzindmK
    safe-0.3.21-L9ANUBcaAdM89WqksxcwDC
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2 time-1.12.2
    transformers-0.6.1.0 uniplate-1.6.13-LJfHyG3GUN7KOQVD2WL0kn
    unix-2.8.4.0 unordered-containers-0.2.21-6KS41JVoQWZ5mM86HX5ZiJ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-CGL8pnIxGMbHvZ63ZDtObP
    vector-binary-instances-0.2.5.2-AHxLzgbczCk4QxLzqQJ4Ur
    zip-archive-0.4.3.2-CpwBawMeecj7gh70NgDjUv

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

